import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import PropTypes from 'prop-types';
import React, { useEffect, useRef, useContext } from 'react';
import AdvertisingContext from '../AdvertisingContext';
import calculateRootMargin from './utils/calculateRootMargin';
import isLazyLoading from './utils/isLazyLoading';
import getLazyLoadConfig from './utils/getLazyLoadConfig';

function AdvertisingSlot(_ref) {
  var id = _ref.id,
      style = _ref.style,
      className = _ref.className,
      children = _ref.children,
      customEventHandlers = _ref.customEventHandlers;
  var observerRef = useRef(null);
  var containerDivRef = useRef();

  var _useContext = useContext(AdvertisingContext),
      activate = _useContext.activate,
      config = _useContext.config;

  var lazyLoadConfig = getLazyLoadConfig(config, id);
  var isLazyLoadEnabled = isLazyLoading(lazyLoadConfig);
  useEffect(function () {
    if (!config || !isLazyLoadEnabled) {
      return function () {};
    }

    var rootMargin = calculateRootMargin(lazyLoadConfig);
    observerRef.current = new IntersectionObserver(function (_ref2) {
      var _ref3 = _slicedToArray(_ref2, 1),
          isIntersecting = _ref3[0].isIntersecting;

      if (isIntersecting) {
        activate(id, customEventHandlers);
        observerRef.current.unobserve(containerDivRef.current);
      }
    }, {
      rootMargin: rootMargin
    });
    observerRef.current.observe(containerDivRef.current);
    return function () {
      observerRef.current.unobserve(containerDivRef.current);
    };
  }, [activate, config]);
  useEffect(function () {
    if (!config || isLazyLoadEnabled) {
      return;
    }

    activate(id, customEventHandlers);
  }, [activate, config]);
  return /*#__PURE__*/React.createElement("div", {
    id: id,
    style: style,
    className: className,
    children: children,
    ref: containerDivRef
  });
}

AdvertisingSlot.propTypes = {
  id: PropTypes.string.isRequired,
  style: PropTypes.object,
  className: PropTypes.string,
  children: PropTypes.node,
  customEventHandlers: PropTypes.objectOf(PropTypes.func).isRequired
};
AdvertisingSlot.defaultProps = {
  customEventHandlers: {}
};
export default AdvertisingSlot;